#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ==============================================================================
# author          :Ghislain Vieilledent
# email           :ghislain.vieilledent@cirad.fr, ghislainv@gmail.com
# web             :https://ecology.ghislainv.fr
# python_version  :>=2.7
# license         :GPLv3
# ==============================================================================

# Import
import os.path
import pywdpa


# test_get_wdpa
def test_get_wdpa():
  #pywdpa.get_wdpa("MDG")
  #f = os.path.isfile("pa_MDG.shp")
  #assert f is True
  f = "File"
  assert f == "File"

# End
