#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ==============================================================================
# author          :Ghislain Vieilledent
# email           :ghislain.vieilledent@cirad.fr, ghislainv@gmail.com
# web             :https://ecology.ghislainv.fr
# python_version  :>=2.7
# license         :GPLv3
# ==============================================================================

"""Convenience wrapper for running pywdpa directly from source tree.
See https://gehrcke.de/2014/02/distributing-a-python-command-line-application/
"""

from pywdpa.pywdpa import main

if __name__ == '__main__':
    main()

# End
